" Vim syntax file
" Language:     BAF and D
"" Used by Bioware's Infinity Engine for scripting
" Filenames:    *.baf *.d
" Maintainer:   Wes Weimer <weimer@cs.berkeley.edu>
" URL:          http://www.cs.berkeley.edu/~weimer/bgate
" Last Change:  2002 Mar 07 - Created

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

" Errors
syn match    dotParErr     ")"
syn match    dotBrackErr   "]"
syn match    dotBraceErr   "}"

" Enclosing delimiters
syn region   dotEncl transparent matchgroup=dotParEncl start="(" matchgroup=dotParEncl end=")" contains=ALLBUT,dotParErr
syn region   dotEncl transparent matchgroup=dotBrackEncl start="\[" matchgroup=dotBrackEncl end="\]" contains=ALLBUT,dotBrackErr
syn region   dotEncl transparent matchgroup=dotBraceEncl start="{" matchgroup=dotBraceEncl end="}" contains=ALLBUT,dotBraceErr

" Comments
syn region   dotComment start="//" end="$" contains=dotTodo
syn region   dotComment start="/\*" end="\*/" contains=dotTodo
syn keyword  dotTodo contained TODO FIXME XXX

" Strings
syn region   dotString    start=+"+ skip=+\\\\\|\\"+ end=+"+
syn region   dotString    start=+\~+ skip=+\\\\\|\\\~+ end=+\~+

" General keywords
      syn keyword dotKeyword ADD_STATE_TRIGGER
      syn keyword dotKeyword ADD_TRANS_TRIGGER
      syn keyword dotKeyword APPEND
      syn keyword dotKeyword APPENDI
      syn keyword dotKeyword AT_EXIT
      syn keyword dotKeyword AUTHOR
      syn keyword dotKeyword BACKUP
      syn keyword dotKeyword BEGIN
      syn keyword dotKeyword CHAIN
      syn keyword dotKeyword CHAIN2
      syn keyword dotKeyword COMPILE
      syn keyword dotKeyword COPY
      syn keyword dotKeyword DO
      syn keyword dotKeyword END
      syn keyword dotKeyword EXIT
      syn keyword dotKeyword EXTEND_BOTTOM
      syn keyword dotKeyword EXTEND_TOP
      syn keyword dotKeyword EXTEND
      syn keyword dotKeyword EXTERN
      syn keyword dotKeyword FLAGS
      syn keyword dotKeyword GOTO
      syn keyword dotKeyword IF
      syn keyword dotKeyword JOURNAL
      syn keyword dotKeyword LANGUAGE
      syn keyword dotKeyword REPLACE
      syn keyword dotKeyword REPLY
      syn keyword dotKeyword SAY
      syn keyword dotKeyword THEN
      syn keyword dotKeyword UNLESS
      syn keyword dotKeyword USING

syn match  dotType "@\d*"
syn match  dotType "#\d*"

syn keyword dotType Myself
syn match dotType "Player\d"

syn match    dotKeyChar  "="
syn match    dotKeyChar  ","
syn match    dotKeyChar  "=="

" Synchronization
syn sync minlines=50
syn sync maxlines=500

" Define the default highlighting.
" For version 5.7 and earlier: only when not done already
" For version 5.8 and later: only when an item doesn't have highlighting yet
if version >= 508 || !exists("did_dot_syntax_inits")
  if version < 508
    let did_dot_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif

  HiLink dotParErr       Error
  HiLink dotBraceErr     Error
  HiLink dotBrackErr     Error

  HiLink dotComment      Comment
  HiLink dotTodo         Todo

  HiLink dotParEncl      Keyword
  HiLink dotBrackEncl    Type
  HiLink dotBraceEncl    Keyword

  HiLink dotKeyword      Keyword
  HiLink dotType         Type
  HiLink dotKeyChar      Keyword

  HiLink dotString       String
  HiLink dotIdentifier   Identifier

  delcommand HiLink
endif

let b:current_syntax = "bafd"

" vim: ts=28
